@@ -1,27 +1,11 @@
 /*
   This file is part of KOrganizer.
 
-  Copyright (c) 1998 Preston Brown <pbrown@kde.org>
-  Copyright (c) 2000,2001 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 1998 Preston Brown <pbrown@kde.org>
+  SPDX-FileCopyrightText: 2000, 2001 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #ifndef KORG_SEARCHDIALOG_H
@@ -76,8 +60,8 @@ private:
     void writeConfig();
     void updateMatchesText();
 
-    Ui::SearchDialog *m_ui = nullptr;
-    CalendarView *m_calendarview = nullptr; // parent
+    Ui::SearchDialog *const m_ui;
+    CalendarView *const m_calendarview; // parent
     KOEventPopupMenu *m_popupMenu = nullptr;
     Akonadi::Item::List mMatchedEvents;
     EventViews::ListView *listView = nullptr;
