@@ -1,29 +1,13 @@
 /*
   This file is part of KOrganizer.
 
-  Copyright (c) 2001 Eitzenberger Thomas <thomas.eitzenberger@siemens.at>
+  SPDX-FileCopyrightText: 2001 Eitzenberger Thomas <thomas.eitzenberger@siemens.at>
   Parts of the source code have been copied from kdpdatebutton.cpp
 
-  Copyright (c) 2003 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2003 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "kodaymatrix.h"
@@ -55,7 +39,6 @@ const int KODayMatrix::NUMDAYS = 42;
 KODayMatrix::KODayMatrix(QWidget *parent)
     : QFrame(parent)
     , mStartDate()
-    , mPendingChanges(false)
 {
     // initialize dynamic arrays
     mDays = new QDate[NUMDAYS];
@@ -140,7 +123,7 @@ void KODayMatrix::addSelectedDaysTo(KCalendarCore::DateList &selDays)
     }
 }
 
-void KODayMatrix::setSelectedDaysFrom(const QDate &start, const QDate &end)
+void KODayMatrix::setSelectedDaysFrom(QDate start, QDate end)
 {
     if (mStartDate.isValid()) {
         mSelStart = mStartDate.daysTo(start);
@@ -183,7 +166,7 @@ void KODayMatrix::setUpdateNeeded()
     mPendingChanges = true;
 }
 
-void KODayMatrix::updateView(const QDate &actdate)
+void KODayMatrix::updateView(QDate actdate)
 {
     if (!actdate.isValid() || NUMDAYS < 1) {
         return;
@@ -478,7 +461,7 @@ void KODayMatrix::resourcesChanged()
 bool KODayMatrix::event(QEvent *event)
 {
     if (KOPrefs::instance()->mEnableToolTips && event->type() == QEvent::ToolTip) {
-        QHelpEvent *helpEvent = static_cast<QHelpEvent *>(event);
+        auto *helpEvent = static_cast<QHelpEvent *>(event);
 
         // calculate which cell of the matrix the mouse is in
         QRect sz = frameRect();
@@ -672,12 +655,12 @@ void KODayMatrix::dropEvent(QDropEvent *e)
             action = DRAG_MOVE;
         } else {
             QAction *copy = nullptr, *move = nullptr;
-            QMenu *menu = new QMenu(this);
+            auto *menu = new QMenu(this);
             if (exist) {
                 move
                     = menu->addAction(QIcon::fromTheme(QStringLiteral("edit-paste")),
                                       i18n("&Move"));
-                if (/*existingEvent*/ 1) {
+                if (/*existingEvent*/ true) {
                     copy
                         = menu->addAction(QIcon::fromTheme(QStringLiteral("edit-copy")),
                                           i18n("&Copy"));
@@ -884,7 +867,7 @@ void KODayMatrix::resizeEvent(QResizeEvent *)
 }
 
 /* static */
-QPair<QDate, QDate> KODayMatrix::matrixLimits(const QDate &month)
+QPair<QDate, QDate> KODayMatrix::matrixLimits(QDate month)
 {
     QDate d(month.year(), month.month(), 1);
 
