@@ -1,26 +1,10 @@
 /*
   This file is part of KOrganizer.
 
-  Copyright (c) 1997-1999 Preston Brown <pbrown@kde.org>
-  Copyright (c) 2001,2003 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 1997-1999 Preston Brown <pbrown@kde.org>
+  SPDX-FileCopyrightText: 2001, 2003 Cornelius Schumacher <schumacher@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "aboutdata.h"
@@ -29,12 +13,12 @@
 #include "korganizer_options.h"
 #include "korganizer_debug.h"
 #include "korgmigrateapplication.h"
+#include <KLocalizedString>
+#include <KCrash>
 
 #ifdef WITH_KUSERFEEDBACK
 #include "userfeedback/korganizeruserfeedbackprovider.h"
 #endif
-#include <KLocalizedString>
-#include <KCrash>
 int main(int argc, char **argv)
 {
     QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
@@ -57,7 +41,7 @@ int main(int argc, char **argv)
 
 #ifdef WITH_KUSERFEEDBACK
     if (cmdArgs->isSet(QStringLiteral("feedback"))) {
-        KOrganizerUserFeedbackProvider *userFeedBackProvider = new KOrganizerUserFeedbackProvider(nullptr);
+        auto *userFeedBackProvider = new KOrganizerUserFeedbackProvider(nullptr);
         QTextStream(stdout) << userFeedBackProvider->describeDataSources() << '\n';
         return 0;
     }
